Function blosc_sys::blosc_compcode_to_compname
[−]
[src]
pub unsafe extern "C" fn blosc_compcode_to_compname(
compcode: c_int,
copmname: *mut *mut c_char
) -> c_int
Get the compname associated with the compcode.
If the compressor code is not recognized, or there is not support for it in this build, -1 is returned. Else, the compressor code is returned.